import type { IValidatable } from './IValidatable';
import { ViewModel } from '../viewModels';
/**
 * Represents a base implementation for a validatable
 * @template TValidationError The concrete type for representing validation errors (strings, enums, numbers etc.).
 */
export declare class Validatable<TValidationError = string> extends ViewModel implements IValidatable<TValidationError> {
    private _error;
    /**
     * Initializes a new instance of the {@linkcode Validatable} class.
     */
    constructor();
    /**
     * A flag indicating whether the object is valid.
     */
    get isValid(): boolean;
    /**
     * A flag indicating whether the object is invalid.
     */
    get isInvalid(): boolean;
    /**
     * Gets or sets the error message when the object is invalid.
     */
    get error(): TValidationError | null;
    /**
     * Gets or sets the error message when the object is invalid.
     */
    set error(value: TValidationError | false | null | undefined);
}
